@@ -40,20 +40,25 @@ class BinaryAUROC(BinaryPrecisionRecallCurve):
     thresholds at the same time. Notably, an AUROC score of 1 is a perfect score and an AUROC score of 0.5
     corresponds to random guessing.
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (float tensor): ``(N, ...)``. Preds should be a tensor containing probabilities or logits for each
-      observation. If preds has values outside [0,1] range we consider the input to be logits and will auto apply
+    - ``preds`` (:class:`~torch.Tensor`): A float tensor of shape ``(N, ...)`` containing probabilities or logits for
+      each observation. If preds has values outside [0,1] range we consider the input to be logits and will auto apply
       sigmoid per element.
-    - ``target`` (int tensor): ``(N, ...)``. Target should be a tensor containing ground truth labels, and therefore
-      only contain {0,1} values (except if `ignore_index` is specified).
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)`` containing ground truth labels, and
+      therefore only contain {0,1} values (except if `ignore_index` is specified). The value 1 always encodes the
+      positive class.
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``b_auroc`` (:class:`~torch.Tensor`): A single scalar with the auroc score.
 
     Additional dimension ``...`` will be flattened into the batch dimension.
 
-    The implementation both supports calculating the metric in a non-binned but accurate version and a binned version
-    that is less accurate but more memory efficient. Setting the `thresholds` argument to `None` will activate the
-    non-binned  version that uses memory of size :math:`\mathcal{O}(n_{samples})` whereas setting the `thresholds`
-    argument to either an integer, list or a 1d tensor will use a binned version that uses memory of
+    The implementation both supports calculating the metric in a non-binned but accurate version and a
+    binned version that is less accurate but more memory efficient. Setting the `thresholds` argument to `None` will
+    activate the non-binned  version that uses memory of size :math:`\mathcal{O}(n_{samples})` whereas setting the
+    `thresholds` argument to either an integer, list or a 1d tensor will use a binned version that uses memory of
     size :math:`\mathcal{O}(n_{thresholds})` (constant memory).
 
     Args:
@@ -73,9 +78,6 @@ class BinaryAUROC(BinaryPrecisionRecallCurve):
             Set to ``False`` for faster computations.
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
-    Returns:
-        A single scalar with the auroc score
-
     Example:
         >>> from torchmetrics.classification import BinaryAUROC
         >>> preds = torch.tensor([0, 0.5, 0.7, 0.8])
@@ -83,8 +85,8 @@ class BinaryAUROC(BinaryPrecisionRecallCurve):
         >>> metric = BinaryAUROC(thresholds=None)
         >>> metric(preds, target)
         tensor(0.5000)
-        >>> metric = BinaryAUROC(thresholds=5)
-        >>> metric(preds, target)
+        >>> b_auroc = BinaryAUROC(thresholds=5)
+        >>> b_auroc(preds, target)
         tensor(0.5000)
     """
     is_differentiable: bool = False
@@ -118,13 +120,18 @@ class MulticlassAUROC(MulticlassPrecisionRecallCurve):
     thresholds at the same time. Notably, an AUROC score of 1 is a perfect score and an AUROC score of 0.5
     corresponds to random guessing.
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (float tensor): ``(N, C, ...)``. Preds should be a tensor containing probabilities or logits for each
-      observation. If preds has values outside [0,1] range we consider the input to be logits and will auto apply
-      softmax per sample.
-    - ``target`` (int tensor): ``(N, ...)``. Target should be a tensor containing ground truth labels, and therefore
-      only contain values in the [0, n_classes-1] range (except if `ignore_index` is specified).
+    - ``preds`` (:class:`~torch.Tensor`): A float tensor of shape ``(N, C, ...)`` containing probabilities or logits
+      for each observation. If preds has values outside [0,1] range we consider the input to be logits and will auto
+      apply softmax per sample.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)`` containing ground truth labels, and
+      therefore only contain values in the [0, n_classes-1] range (except if `ignore_index` is specified).
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``mc_auroc`` (:class:`~torch.Tensor`): If `average=None|"none"` then a 1d tensor of shape (n_classes, ) will
+      be returned with auroc score per class. If `average="macro"|"weighted"` then a single scalar is returned.
 
     Additional dimension ``...`` will be flattened into the batch dimension.
 
@@ -158,10 +165,6 @@ class MulticlassAUROC(MulticlassPrecisionRecallCurve):
             Set to ``False`` for faster computations.
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
-    Returns:
-        If `average=None|"none"` then a 1d tensor of shape (n_classes, ) will be returned with auroc score per class.
-        If `average="macro"|"weighted"` then a single scalar is returned.
-
     Example:
         >>> from torchmetrics.classification import MulticlassAUROC
         >>> preds = torch.tensor([[0.75, 0.05, 0.05, 0.05, 0.05],
@@ -172,14 +175,14 @@ class MulticlassAUROC(MulticlassPrecisionRecallCurve):
         >>> metric = MulticlassAUROC(num_classes=5, average="macro", thresholds=None)
         >>> metric(preds, target)
         tensor(0.5333)
-        >>> metric = MulticlassAUROC(num_classes=5, average=None, thresholds=None)
-        >>> metric(preds, target)
+        >>> mc_auroc = MulticlassAUROC(num_classes=5, average=None, thresholds=None)
+        >>> mc_auroc(preds, target)
         tensor([1.0000, 1.0000, 0.3333, 0.3333, 0.0000])
-        >>> metric = MulticlassAUROC(num_classes=5, average="macro", thresholds=5)
-        >>> metric(preds, target)
+        >>> mc_auroc = MulticlassAUROC(num_classes=5, average="macro", thresholds=5)
+        >>> mc_auroc(preds, target)
         tensor(0.5333)
-        >>> metric = MulticlassAUROC(num_classes=5, average=None, thresholds=5)
-        >>> metric(preds, target)
+        >>> mc_auroc = MulticlassAUROC(num_classes=5, average=None, thresholds=5)
+        >>> mc_auroc(preds, target)
         tensor([1.0000, 1.0000, 0.3333, 0.3333, 0.0000])
     """
 
@@ -218,13 +221,18 @@ class MultilabelAUROC(MultilabelPrecisionRecallCurve):
     thresholds at the same time. Notably, an AUROC score of 1 is a perfect score and an AUROC score of 0.5
     corresponds to random guessing.
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (float tensor): ``(N, C, ...)``. Preds should be a tensor containing probabilities or logits for each
-      observation. If preds has values outside [0,1] range we consider the input to be logits and will auto apply
-      sigmoid per element.
-    - ``target`` (int tensor): ``(N, C, ...)``. Target should be a tensor containing ground truth labels, and therefore
-      only contain {0,1} values (except if `ignore_index` is specified).
+    - ``preds`` (:class:`~torch.Tensor`): A float tensor of shape ``(N, C, ...)`` containing probabilities or logits
+      for each observation. If preds has values outside [0,1] range we consider the input to be logits and will auto
+      apply sigmoid per element.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, C, ...)`` containing ground truth labels, and
+      therefore only contain {0,1} values (except if `ignore_index` is specified).
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``ml_auroc`` (:class:`~torch.Tensor`): If `average=None|"none"` then a 1d tensor of shape (n_classes, ) will
+      be returned with auroc score per class. If `average="micro|macro"|"weighted"` then a single scalar is returned.
 
     Additional dimension ``...`` will be flattened into the batch dimension.
 
@@ -258,10 +266,6 @@ class MultilabelAUROC(MultilabelPrecisionRecallCurve):
             Set to ``False`` for faster computations.
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
-    Returns:
-        If `average=None|"none"` then a 1d tensor of shape (n_classes, ) will be returned with auroc score per class.
-        If `average="micro|macro"|"weighted"` then a single scalar is returned.
-
     Example:
         >>> from torchmetrics.classification import MultilabelAUROC
         >>> preds = torch.tensor([[0.75, 0.05, 0.35],
@@ -272,17 +276,17 @@ class MultilabelAUROC(MultilabelPrecisionRecallCurve):
         ...                        [0, 0, 0],
         ...                        [0, 1, 1],
         ...                        [1, 1, 1]])
-        >>> metric = MultilabelAUROC(num_labels=3, average="macro", thresholds=None)
-        >>> metric(preds, target)
+        >>> ml_auroc = MultilabelAUROC(num_labels=3, average="macro", thresholds=None)
+        >>> ml_auroc(preds, target)
         tensor(0.6528)
-        >>> metric = MultilabelAUROC(num_labels=3, average=None, thresholds=None)
-        >>> metric(preds, target)
+        >>> ml_auroc = MultilabelAUROC(num_labels=3, average=None, thresholds=None)
+        >>> ml_auroc(preds, target)
         tensor([0.6250, 0.5000, 0.8333])
-        >>> metric = MultilabelAUROC(num_labels=3, average="macro", thresholds=5)
-        >>> metric(preds, target)
+        >>> ml_auroc = MultilabelAUROC(num_labels=3, average="macro", thresholds=5)
+        >>> ml_auroc(preds, target)
         tensor(0.6528)
-        >>> metric = MultilabelAUROC(num_labels=3, average=None, thresholds=5)
-        >>> metric(preds, target)
+        >>> ml_auroc = MultilabelAUROC(num_labels=3, average=None, thresholds=5)
+        >>> ml_auroc(preds, target)
         tensor([0.6250, 0.5000, 0.8333])
     """
     is_differentiable: bool = False
