@@ -34,15 +34,21 @@ class BinaryFBetaScore(BinaryStatScores):
         F_{\beta} = (1 + \beta^2) * \frac{\text{precision} * \text{recall}}
         {(\beta^2 * \text{precision}) + \text{recall}}
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (int or float tensor): ``(N, ...)``. If preds is a floating point tensor with values outside
-      [0,1] range we consider the input to be logits and will auto apply sigmoid per element. Addtionally,
-      we convert to int tensor with thresholding using the value in ``threshold``.
-    - ``target`` (int tensor): ``(N, ...)``
+    - ``preds`` (:class:`~torch.Tensor`): An int tensor or float tensor of shape ``(N, ...)``. If preds is a floating
+      point tensor with values outside [0,1] range we consider the input to be logits and will auto apply sigmoid
+      per element. Addtionally, we convert to int tensor with thresholding using the value in ``threshold``.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)``.
 
-    The influence of the additional dimension ``...`` (if present) will be determined by the `multidim_average`
-    argument.
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``bfbs`` (:class:`~torch.Tensor`): A tensor whose returned shape depends on the ``multidim_average`` argument:
+
+        - If ``multidim_average`` is set to ``global`` the output will be a scalar tensor
+        - If ``multidim_average`` is set to ``samplewise`` the output will be a tensor of shape ``(N,)`` consisting of
+          a scalar value per sample.
 
     Args:
         beta: Weighting between precision and recall in calculation. Setting to 1 corresponds to equal weight
@@ -59,10 +65,6 @@ class BinaryFBetaScore(BinaryStatScores):
         validate_args: bool indicating if input arguments and tensors should be validated for correctness.
             Set to ``False`` for faster computations.
 
-    Returns:
-        If ``multidim_average`` is set to ``global``, the metric returns a scalar value. If ``multidim_average``
-        is set to ``samplewise``, the metric returns ``(N,)`` vector consisting of a scalar value per sample.
-
     Example (preds is int tensor):
         >>> from torchmetrics.classification import BinaryFBetaScore
         >>> target = torch.tensor([0, 1, 0, 1, 0, 1])
@@ -129,15 +131,28 @@ class MulticlassFBetaScore(MulticlassStatScores):
         F_{\beta} = (1 + \beta^2) * \frac{\text{precision} * \text{recall}}
         {(\beta^2 * \text{precision}) + \text{recall}}
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds``: ``(N, ...)`` (int tensor) or ``(N, C, ..)`` (float tensor). If preds is a floating point
-      we apply ``torch.argmax`` along the ``C`` dimension to automatically convert probabilities/logits into
-      an int tensor.
-    - ``target`` (int tensor): ``(N, ...)``
+    - ``preds`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)`` or float tensor of shape ``(N, C, ..)``.
+      If preds is a floating point we apply ``torch.argmax`` along the ``C`` dimension to automatically convert
+      probabilities/logits into an int tensor.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)``.
 
-    The influence of the additional dimension ``...`` (if present) will be determined by the `multidim_average`
-    argument.
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``mcfbs`` (:class:`~torch.Tensor`): A tensor whose returned shape depends on the ``average`` and
+      ``multidim_average`` arguments:
+
+        - If ``multidim_average`` is set to ``global``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
+          - If ``average=None/'none'``, the shape will be ``(C,)``
+
+        - If ``multidim_average`` is set to ``samplewise``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
+          - If ``average=None/'none'``, the shape will be ``(N, C)``
 
     Args:
         beta: Weighting between precision and recall in calculation. Setting to 1 corresponds to equal weight
@@ -165,19 +180,6 @@ class MulticlassFBetaScore(MulticlassStatScores):
         validate_args: bool indicating if input arguments and tensors should be validated for correctness.
             Set to ``False`` for faster computations.
 
-    Returns:
-        The returned shape depends on the ``average`` and ``multidim_average`` arguments:
-
-        - If ``multidim_average`` is set to ``global``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
-          - If ``average=None/'none'``, the shape will be ``(C,)``
-
-        - If ``multidim_average`` is set to ``samplewise``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
-          - If ``average=None/'none'``, the shape will be ``(N, C)``
-
     Example (preds is int tensor):
         >>> from torchmetrics.classification import MulticlassFBetaScore
         >>> target = torch.tensor([2, 1, 0, 0])
@@ -185,8 +187,8 @@ class MulticlassFBetaScore(MulticlassStatScores):
         >>> metric = MulticlassFBetaScore(beta=2.0, num_classes=3)
         >>> metric(preds, target)
         tensor(0.7963)
-        >>> metric = MulticlassFBetaScore(beta=2.0, num_classes=3, average=None)
-        >>> metric(preds, target)
+        >>> mcfbs = MulticlassFBetaScore(beta=2.0, num_classes=3, average=None)
+        >>> mcfbs(preds, target)
         tensor([0.5556, 0.8333, 1.0000])
 
     Example (preds is float tensor):
@@ -201,8 +203,8 @@ class MulticlassFBetaScore(MulticlassStatScores):
         >>> metric = MulticlassFBetaScore(beta=2.0, num_classes=3)
         >>> metric(preds, target)
         tensor(0.7963)
-        >>> metric = MulticlassFBetaScore(beta=2.0, num_classes=3, average=None)
-        >>> metric(preds, target)
+        >>> mcfbs = MulticlassFBetaScore(beta=2.0, num_classes=3, average=None)
+        >>> mcfbs(preds, target)
         tensor([0.5556, 0.8333, 1.0000])
 
     Example (multidim tensors):
@@ -212,8 +214,8 @@ class MulticlassFBetaScore(MulticlassStatScores):
         >>> metric = MulticlassFBetaScore(beta=2.0, num_classes=3, multidim_average='samplewise')
         >>> metric(preds, target)
         tensor([0.4697, 0.2706])
-        >>> metric = MulticlassFBetaScore(beta=2.0, num_classes=3, multidim_average='samplewise', average=None)
-        >>> metric(preds, target)
+        >>> mcfbs = MulticlassFBetaScore(beta=2.0, num_classes=3, multidim_average='samplewise', average=None)
+        >>> mcfbs(preds, target)
         tensor([[0.9091, 0.0000, 0.5000],
                 [0.0000, 0.3571, 0.4545]])
     """
@@ -258,15 +260,28 @@ class MultilabelFBetaScore(MultilabelStatScores):
         F_{\beta} = (1 + \beta^2) * \frac{\text{precision} * \text{recall}}
         {(\beta^2 * \text{precision}) + \text{recall}}
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (int or float tensor): ``(N, C, ...)``. If preds is a floating point tensor with values outside
-      [0,1] range we consider the input to be logits and will auto apply sigmoid per element. Addtionally,
-      we convert to int tensor with thresholding using the value in ``threshold``.
-    - ``target`` (int tensor): ``(N, C, ...)``
+    - ``preds`` (:class:`~torch.Tensor`): An int or float tensor of shape ``(N, C, ...)``. If preds is a floating
+      point tensor with values outside [0,1] range we consider the input to be logits and will auto apply sigmoid
+      per element. Addtionally, we convert to int tensor with thresholding using the value in ``threshold``.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, C, ...)``.
 
-    The influence of the additional dimension ``...`` (if present) will be determined by the `multidim_average`
-    argument.
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``mlfbs`` (:class:`~torch.Tensor`): A tensor whose returned shape depends on the ``average`` and
+      ``multidim_average`` arguments:
+
+        - If ``multidim_average`` is set to ``global``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
+          - If ``average=None/'none'``, the shape will be ``(C,)``
+
+        - If ``multidim_average`` is set to ``samplewise``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
+          - If ``average=None/'none'``, the shape will be ``(N, C)``
 
     Args:
         beta: Weighting between precision and recall in calculation. Setting to 1 corresponds to equal weight
@@ -292,19 +307,6 @@ class MultilabelFBetaScore(MultilabelStatScores):
         validate_args: bool indicating if input arguments and tensors should be validated for correctness.
             Set to ``False`` for faster computations.
 
-    Returns:
-        The returned shape depends on the ``average`` and ``multidim_average`` arguments:
-
-        - If ``multidim_average`` is set to ``global``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
-          - If ``average=None/'none'``, the shape will be ``(C,)``
-
-        - If ``multidim_average`` is set to ``samplewise``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
-          - If ``average=None/'none'``, the shape will be ``(N, C)``
-
     Example (preds is int tensor):
         >>> from torchmetrics.classification import MultilabelFBetaScore
         >>> target = torch.tensor([[0, 1, 0], [1, 0, 1]])
@@ -312,8 +314,8 @@ class MultilabelFBetaScore(MultilabelStatScores):
         >>> metric = MultilabelFBetaScore(beta=2.0, num_labels=3)
         >>> metric(preds, target)
         tensor(0.6111)
-        >>> metric = MultilabelFBetaScore(beta=2.0, num_labels=3, average=None)
-        >>> metric(preds, target)
+        >>> mlfbs = MultilabelFBetaScore(beta=2.0, num_labels=3, average=None)
+        >>> mlfbs(preds, target)
         tensor([1.0000, 0.0000, 0.8333])
 
     Example (preds is float tensor):
@@ -323,8 +325,8 @@ class MultilabelFBetaScore(MultilabelStatScores):
         >>> metric = MultilabelFBetaScore(beta=2.0, num_labels=3)
         >>> metric(preds, target)
         tensor(0.6111)
-        >>> metric = MultilabelFBetaScore(beta=2.0, num_labels=3, average=None)
-        >>> metric(preds, target)
+        >>> mlfbs = MultilabelFBetaScore(beta=2.0, num_labels=3, average=None)
+        >>> mlfbs(preds, target)
         tensor([1.0000, 0.0000, 0.8333])
 
     Example (multidim tensors):
@@ -339,8 +341,8 @@ class MultilabelFBetaScore(MultilabelStatScores):
         >>> metric = MultilabelFBetaScore(num_labels=3, beta=2.0, multidim_average='samplewise')
         >>> metric(preds, target)
         tensor([0.5556, 0.0000])
-        >>> metric = MultilabelFBetaScore(num_labels=3, beta=2.0, multidim_average='samplewise', average=None)
-        >>> metric(preds, target)
+        >>> mlfbs = MultilabelFBetaScore(num_labels=3, beta=2.0, multidim_average='samplewise', average=None)
+        >>> mlfbs(preds, target)
         tensor([[0.8333, 0.8333, 0.0000],
                 [0.0000, 0.0000, 0.0000]])
     """
@@ -384,15 +386,21 @@ class BinaryF1Score(BinaryFBetaScore):
     .. math::
         F_{1} = 2\frac{\text{precision} * \text{recall}}{(\text{precision}) + \text{recall}}
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (int or float tensor): ``(N, ...)``. If preds is a floating point tensor with values outside
-      [0,1] range we consider the input to be logits and will auto apply sigmoid per element. Addtionally,
-      we convert to int tensor with thresholding using the value in ``threshold``.
-    - ``target`` (int tensor): ``(N, ...)``
+    - ``preds`` (:class:`~torch.Tensor`): An int or float tensor of shape ``(N, ...)``. If preds is a floating point
+      tensor with values outside [0,1] range we consider the input to be logits and will auto apply sigmoid per
+      element. Addtionally, we convert to int tensor with thresholding using the value in ``threshold``.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)``
 
-    The influence of the additional dimension ``...`` (if present) will be determined by the `multidim_average`
-    argument.
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``bf1s`` (:class:`~torch.Tensor`): A tensor whose returned shape depends on the ``multidim_average`` argument:
+
+        - If ``multidim_average`` is set to ``global``, the metric returns a scalar value.
+        - If ``multidim_average`` is set to ``samplewise``, the metric returns ``(N,)`` vector consisting of a scalar
+          value per sample.
 
     Args:
         threshold: Threshold for transforming probability to binary {0,1} predictions
@@ -408,10 +416,6 @@ class BinaryF1Score(BinaryFBetaScore):
         validate_args: bool indicating if input arguments and tensors should be validated for correctness.
             Set to ``False`` for faster computations.
 
-    Returns:
-        If ``multidim_average`` is set to ``global``, the metric returns a scalar value. If ``multidim_average``
-        is set to ``samplewise``, the metric returns ``(N,)`` vector consisting of a scalar value per sample.
-
     Example (preds is int tensor):
         >>> from torchmetrics.classification import BinaryF1Score
         >>> target = torch.tensor([0, 1, 0, 1, 0, 1])
@@ -469,15 +473,28 @@ class MulticlassF1Score(MulticlassFBetaScore):
     .. math::
         F_{1} = 2\frac{\text{precision} * \text{recall}}{(\text{precision}) + \text{recall}}
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds``: ``(N, ...)`` (int tensor) or ``(N, C, ..)`` (float tensor). If preds is a floating point
-      we apply ``torch.argmax`` along the ``C`` dimension to automatically convert probabilities/logits into
-      an int tensor.
-    - ``target`` (int tensor): ``(N, ...)``
+    - ``preds`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)`` or float tensor of shape ``(N, C, ..)``.
+      If preds is a floating point we apply ``torch.argmax`` along the ``C`` dimension to automatically convert
+      probabilities/logits into an int tensor.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)``
 
-    The influence of the additional dimension ``...`` (if present) will be determined by the `multidim_average`
-    argument.
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``mcf1s`` (:class:`~torch.Tensor`): A tensor whose returned shape depends on the ``average`` and
+      ``multidim_average`` arguments:
+
+        - If ``multidim_average`` is set to ``global``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
+          - If ``average=None/'none'``, the shape will be ``(C,)``
+
+        - If ``multidim_average`` is set to ``samplewise``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
+          - If ``average=None/'none'``, the shape will be ``(N, C)``
 
     Args:
         preds: Tensor with predictions
@@ -505,19 +522,6 @@ class MulticlassF1Score(MulticlassFBetaScore):
         validate_args: bool indicating if input arguments and tensors should be validated for correctness.
             Set to ``False`` for faster computations.
 
-    Returns:
-        The returned shape depends on the ``average`` and ``multidim_average`` arguments:
-
-        - If ``multidim_average`` is set to ``global``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
-          - If ``average=None/'none'``, the shape will be ``(C,)``
-
-        - If ``multidim_average`` is set to ``samplewise``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
-          - If ``average=None/'none'``, the shape will be ``(N, C)``
-
     Example (preds is int tensor):
         >>> from torchmetrics.classification import MulticlassF1Score
         >>> target = torch.tensor([2, 1, 0, 0])
@@ -525,8 +529,8 @@ class MulticlassF1Score(MulticlassFBetaScore):
         >>> metric = MulticlassF1Score(num_classes=3)
         >>> metric(preds, target)
         tensor(0.7778)
-        >>> metric = MulticlassF1Score(num_classes=3, average=None)
-        >>> metric(preds, target)
+        >>> mcf1s = MulticlassF1Score(num_classes=3, average=None)
+        >>> mcf1s(preds, target)
         tensor([0.6667, 0.6667, 1.0000])
 
     Example (preds is float tensor):
@@ -541,8 +545,8 @@ class MulticlassF1Score(MulticlassFBetaScore):
         >>> metric = MulticlassF1Score(num_classes=3)
         >>> metric(preds, target)
         tensor(0.7778)
-        >>> metric = MulticlassF1Score(num_classes=3, average=None)
-        >>> metric(preds, target)
+        >>> mcf1s = MulticlassF1Score(num_classes=3, average=None)
+        >>> mcf1s(preds, target)
         tensor([0.6667, 0.6667, 1.0000])
 
     Example (multidim tensors):
@@ -552,8 +556,8 @@ class MulticlassF1Score(MulticlassFBetaScore):
         >>> metric = MulticlassF1Score(num_classes=3, multidim_average='samplewise')
         >>> metric(preds, target)
         tensor([0.4333, 0.2667])
-        >>> metric = MulticlassF1Score(num_classes=3, multidim_average='samplewise', average=None)
-        >>> metric(preds, target)
+        >>> mcf1s = MulticlassF1Score(num_classes=3, multidim_average='samplewise', average=None)
+        >>> mcf1s(preds, target)
         tensor([[0.8000, 0.0000, 0.5000],
                 [0.0000, 0.4000, 0.4000]])
     """
@@ -589,15 +593,29 @@ class MultilabelF1Score(MultilabelFBetaScore):
     .. math::
         F_{1} = 2\frac{\text{precision} * \text{recall}}{(\text{precision}) + \text{recall}}
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (int or float tensor): ``(N, C, ...)``. If preds is a floating point tensor with values outside
-      [0,1] range we consider the input to be logits and will auto apply sigmoid per element. Addtionally,
-      we convert to int tensor with thresholding using the value in ``threshold``.
-    - ``target`` (int tensor): ``(N, C, ...)``
+    - ``preds`` (:class:`~torch.Tensor`): An int or float tensor of shape ``(N, C, ...)``.
+      If preds is a floating point tensor with values outside [0,1] range we consider the input to be logits and
+      will auto apply sigmoid per element. Addtionally, we convert to int tensor with thresholding using the value
+      in ``threshold``.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, C, ...)``.
 
-    The influence of the additional dimension ``...`` (if present) will be determined by the `multidim_average`
-    argument.
+
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``mlf1s`` (:class:`~torch.Tensor`): A tensor whose returned shape depends on the ``average`` and
+      ``multidim_average`` arguments:
+
+        - If ``multidim_average`` is set to ``global``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
+          - If ``average=None/'none'``, the shape will be ``(C,)``
+
+        - If ``multidim_average`` is set to ``samplewise``:
+
+          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
+          - If ``average=None/'none'``, the shape will be ``(N, C)```
 
     Args:
         num_labels: Integer specifing the number of labels
@@ -622,19 +640,6 @@ class MultilabelF1Score(MultilabelFBetaScore):
         validate_args: bool indicating if input arguments and tensors should be validated for correctness.
             Set to ``False`` for faster computations.
 
-    Returns:
-        The returned shape depends on the ``average`` and ``multidim_average`` arguments:
-
-        - If ``multidim_average`` is set to ``global``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the output will be a scalar tensor
-          - If ``average=None/'none'``, the shape will be ``(C,)``
-
-        - If ``multidim_average`` is set to ``samplewise``:
-
-          - If ``average='micro'/'macro'/'weighted'``, the shape will be ``(N,)``
-          - If ``average=None/'none'``, the shape will be ``(N, C)```
-
     Example (preds is int tensor):
         >>> from torchmetrics.classification import MultilabelF1Score
         >>> target = torch.tensor([[0, 1, 0], [1, 0, 1]])
@@ -642,8 +647,8 @@ class MultilabelF1Score(MultilabelFBetaScore):
         >>> metric = MultilabelF1Score(num_labels=3)
         >>> metric(preds, target)
         tensor(0.5556)
-        >>> metric = MultilabelF1Score(num_labels=3, average=None)
-        >>> metric(preds, target)
+        >>> mlf1s = MultilabelF1Score(num_labels=3, average=None)
+        >>> mlf1s(preds, target)
         tensor([1.0000, 0.0000, 0.6667])
 
     Example (preds is float tensor):
@@ -653,8 +658,8 @@ class MultilabelF1Score(MultilabelFBetaScore):
         >>> metric = MultilabelF1Score(num_labels=3)
         >>> metric(preds, target)
         tensor(0.5556)
-        >>> metric = MultilabelF1Score(num_labels=3, average=None)
-        >>> metric(preds, target)
+        >>> mlf1s = MultilabelF1Score(num_labels=3, average=None)
+        >>> mlf1s(preds, target)
         tensor([1.0000, 0.0000, 0.6667])
 
     Example (multidim tensors):
@@ -669,8 +674,8 @@ class MultilabelF1Score(MultilabelFBetaScore):
         >>> metric = MultilabelF1Score(num_labels=3, multidim_average='samplewise')
         >>> metric(preds, target)
         tensor([0.4444, 0.0000])
-        >>> metric = MultilabelF1Score(num_labels=3, multidim_average='samplewise', average=None)
-        >>> metric(preds, target)
+        >>> mlf1s = MultilabelF1Score(num_labels=3, multidim_average='samplewise', average=None)
+        >>> mlf1s(preds, target)
         tensor([[0.6667, 0.6667, 0.0000],
                 [0.0000, 0.0000, 0.0000]])
     """
