@@ -43,21 +43,38 @@ class BinaryPrecisionRecallCurve(Metric):
     r"""Computes the precision-recall curve for binary tasks. The curve consist of multiple pairs of precision and
     recall values evaluated at different thresholds, such that the tradeoff between the two values can been seen.
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (float tensor): ``(N, ...)``. Preds should be a tensor containing probabilities or logits for each
-      observation. If preds has values outside [0,1] range we consider the input to be logits and will auto apply
-      sigmoid per element.
-    - ``target`` (int tensor): ``(N, ...)``. Target should be a tensor containing ground truth labels, and therefore
-      only contain {0,1} values (except if `ignore_index` is specified).
+    - ``preds`` (:class:`~torch.Tensor`): A float tensor of shape ``(N, ...)``. Preds should be a tensor containing
+      probabilities or logits for each observation. If preds has values outside [0,1] range we consider the input
+      to be logits and will auto apply sigmoid per element.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)``. Target should be a tensor containing
+      ground truth labels, and therefore only contain {0,1} values (except if `ignore_index` is specified). The value
+      1 always encodes the positive class.
 
-    Additional dimension ``...`` will be flattened into the batch dimension.
+    .. note::
+       Additional dimension ``...`` will be flattened into the batch dimension.
 
-    The implementation both supports calculating the metric in a non-binned but accurate version and a binned version
-    that is less accurate but more memory efficient. Setting the `thresholds` argument to `None` will activate the
-    non-binned  version that uses memory of size :math:`\mathcal{O}(n_{samples})` whereas setting the `thresholds`
-    argument to either an integer, list or a 1d tensor will use a binned version that uses memory of
-    size :math:`\mathcal{O}(n_{thresholds})` (constant memory).
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``precision`` (:class:`~torch.Tensor`): if `thresholds=None` a list for each class is returned with an 1d
+      tensor of size ``(n_thresholds+1, )`` with precision values (length may differ between classes). If `thresholds`
+      is set to something else, then a single 2d tensor of size ``(n_classes, n_thresholds+1)`` with precision values
+      is returned.
+    - ``recall`` (:class:`~torch.Tensor`): if `thresholds=None` a list for each class is returned with an 1d tensor
+      of size ``(n_thresholds+1, )`` with recall values (length may differ between classes). If `thresholds` is set to
+      something else, then a single 2d tensor of size ``(n_classes, n_thresholds+1)`` with recall values is returned.
+    - ``thresholds`` (:class:`~torch.Tensor`): if `thresholds=None` a list for each class is returned with an 1d
+      tensor of size ``(n_thresholds, )`` with increasing threshold values (length may differ between classes). If
+      `threshold` is set to something else, then a single 1d tensor of size ``(n_thresholds, )`` is returned with
+      shared threshold values for all classes.
+
+    .. note::
+       The implementation both supports calculating the metric in a non-binned but accurate version and a binned version
+       that is less accurate but more memory efficient. Setting the `thresholds` argument to `None` will activate the
+       non-binned  version that uses memory of size :math:`\mathcal{O}(n_{samples})` whereas setting the `thresholds`
+       argument to either an integer, list or a 1d tensor will use a binned version that uses memory of
+       size :math:`\mathcal{O}(n_{thresholds})` (constant memory).
 
     Args:
         thresholds:
@@ -75,24 +92,17 @@ class BinaryPrecisionRecallCurve(Metric):
             Set to ``False`` for faster computations.
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
-    Returns:
-        (tuple): a tuple of 3 tensors containing:
-
-        - precision: an 1d tensor of size (n_thresholds+1, ) with precision values
-        - recall: an 1d tensor of size (n_thresholds+1, ) with recall values
-        - thresholds: an 1d tensor of size (n_thresholds, ) with increasing threshold values
-
     Example:
         >>> from torchmetrics.classification import BinaryPrecisionRecallCurve
         >>> preds = torch.tensor([0, 0.5, 0.7, 0.8])
         >>> target = torch.tensor([0, 1, 1, 0])
-        >>> metric = BinaryPrecisionRecallCurve(thresholds=None)
-        >>> metric(preds, target)  # doctest: +NORMALIZE_WHITESPACE
+        >>> bprc = BinaryPrecisionRecallCurve(thresholds=None)
+        >>> bprc(preds, target)  # doctest: +NORMALIZE_WHITESPACE
         (tensor([0.6667, 0.5000, 0.0000, 1.0000]),
          tensor([1.0000, 0.5000, 0.0000, 0.0000]),
          tensor([0.5000, 0.7000, 0.8000]))
-        >>> metric = BinaryPrecisionRecallCurve(thresholds=5)
-        >>> metric(preds, target)  # doctest: +NORMALIZE_WHITESPACE
+        >>> bprc = BinaryPrecisionRecallCurve(thresholds=5)
+        >>> bprc(preds, target)  # doctest: +NORMALIZE_WHITESPACE
         (tensor([0.5000, 0.6667, 0.6667, 0.0000, 0.0000, 1.0000]),
          tensor([1., 1., 1., 0., 0., 0.]),
          tensor([0.0000, 0.2500, 0.5000, 0.7500, 1.0000]))
@@ -150,21 +160,30 @@ class MulticlassPrecisionRecallCurve(Metric):
     and recall values evaluated at different thresholds, such that the tradeoff between the two values can been
     seen.
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (float tensor): ``(N, C, ...)``. Preds should be a tensor containing probabilities or logits for each
-      observation. If preds has values outside [0,1] range we consider the input to be logits and will auto apply
-      softmax per sample.
-    - ``target`` (int tensor): ``(N, ...)``. Target should be a tensor containing ground truth labels, and therefore
-      only contain values in the [0, n_classes-1] range (except if `ignore_index` is specified).
+    - ``preds`` (:class:`~torch.Tensor`): A float tensor of shape ``(N, C, ...)``. Preds should be a tensor containing
+      probabilities or logits for each observation. If preds has values outside [0,1] range we consider the input to
+      be logits and will auto apply softmax per sample.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, ...)``. Target should be a tensor containing
+      ground truth labels, and therefore only contain values in the [0, n_classes-1] range (except if `ignore_index`
+      is specified).
 
-    Additional dimension ``...`` will be flattened into the batch dimension.
+    .. note::
+       Additional dimension ``...`` will be flattened into the batch dimension.
 
-    The implementation both supports calculating the metric in a non-binned but accurate version and a binned version
-    that is less accurate but more memory efficient. Setting the `thresholds` argument to `None` will activate the
-    non-binned  version that uses memory of size :math:`\mathcal{O}(n_{samples})` whereas setting the `thresholds`
-    argument to either an integer, list or a 1d tensor will use a binned version that uses memory of
-    size :math:`\mathcal{O}(n_{thresholds} \times n_{classes})` (constant memory).
+    As output to ``forward`` and ``compute`` the metric returns the following output:
+
+    - ``precision`` (:class:`~torch.Tensor`): A 1d tensor of size ``(n_thresholds+1, )`` with precision values
+    - ``recall`` (:class:`~torch.Tensor`): A 1d tensor of size ``(n_thresholds+1, )`` with recall values
+    - ``thresholds`` (:class:`~torch.Tensor`): A 1d tensor of size ``(n_thresholds, )`` with increasing threshold values
+
+    .. note::
+       The implementation both supports calculating the metric in a non-binned but accurate version and a binned version
+       that is less accurate but more memory efficient. Setting the `thresholds` argument to `None` will activate the
+       non-binned  version that uses memory of size :math:`\mathcal{O}(n_{samples})` whereas setting the `thresholds`
+       argument to either an integer, list or a 1d tensor will use a binned version that uses memory of
+       size :math:`\mathcal{O}(n_{thresholds} \times n_{classes})` (constant memory).
 
     Args:
         num_classes: Integer specifing the number of classes
@@ -183,19 +202,6 @@ class MulticlassPrecisionRecallCurve(Metric):
             Set to ``False`` for faster computations.
         kwargs: Additional keyword arguments, see :ref:`Metric kwargs` for more info.
 
-    Returns:
-        (tuple): a tuple of either 3 tensors or 3 lists containing
-
-        - precision: if `thresholds=None` a list for each class is returned with an 1d tensor of size (n_thresholds+1, )
-          with precision values (length may differ between classes). If `thresholds` is set to something else,
-          then a single 2d tensor of size (n_classes, n_thresholds+1) with precision values is returned.
-        - recall: if `thresholds=None` a list for each class is returned with an 1d tensor of size (n_thresholds+1, )
-          with recall values (length may differ between classes). If `thresholds` is set to something else,
-          then a single 2d tensor of size (n_classes, n_thresholds+1) with recall values is returned.
-        - thresholds: if `thresholds=None` a list for each class is returned with an 1d tensor of size (n_thresholds, )
-          with increasing threshold values (length may differ between classes). If `threshold` is set to something else,
-          then a single 1d tensor of size (n_thresholds, ) is returned with shared threshold values for all classes.
-
     Example:
         >>> from torchmetrics.classification import MulticlassPrecisionRecallCurve
         >>> preds = torch.tensor([[0.75, 0.05, 0.05, 0.05, 0.05],
@@ -203,8 +209,8 @@ class MulticlassPrecisionRecallCurve(Metric):
         ...                       [0.05, 0.05, 0.75, 0.05, 0.05],
         ...                       [0.05, 0.05, 0.05, 0.75, 0.05]])
         >>> target = torch.tensor([0, 1, 3, 2])
-        >>> metric = MulticlassPrecisionRecallCurve(num_classes=5, thresholds=None)
-        >>> precision, recall, thresholds = metric(preds, target)
+        >>> mcprc = MulticlassPrecisionRecallCurve(num_classes=5, thresholds=None)
+        >>> precision, recall, thresholds = mcprc(preds, target)
         >>> precision  # doctest: +NORMALIZE_WHITESPACE
         [tensor([1., 1.]), tensor([1., 1.]), tensor([0.2500, 0.0000, 1.0000]),
          tensor([0.2500, 0.0000, 1.0000]), tensor([0., 1.])]
@@ -212,8 +218,8 @@ class MulticlassPrecisionRecallCurve(Metric):
         [tensor([1., 0.]), tensor([1., 0.]), tensor([1., 0., 0.]), tensor([1., 0., 0.]), tensor([nan, 0.])]
         >>> thresholds
         [tensor(0.7500), tensor(0.7500), tensor([0.0500, 0.7500]), tensor([0.0500, 0.7500]), tensor(0.0500)]
-        >>> metric = MulticlassPrecisionRecallCurve(num_classes=5, thresholds=5)
-        >>> metric(preds, target)  # doctest: +NORMALIZE_WHITESPACE
+        >>> mcprc = MulticlassPrecisionRecallCurve(num_classes=5, thresholds=5)
+        >>> mcprc(preds, target)  # doctest: +NORMALIZE_WHITESPACE
         (tensor([[0.2500, 1.0000, 1.0000, 1.0000, 0.0000, 1.0000],
                  [0.2500, 1.0000, 1.0000, 1.0000, 0.0000, 1.0000],
                  [0.2500, 0.0000, 0.0000, 0.0000, 0.0000, 1.0000],
@@ -285,21 +291,39 @@ class MultilabelPrecisionRecallCurve(Metric):
     and recall values evaluated at different thresholds, such that the tradeoff between the two values can been
     seen.
 
-    Accepts the following input tensors:
+    As input to ``forward`` and ``update`` the metric accepts the following input:
 
-    - ``preds`` (float tensor): ``(N, C, ...)``. Preds should be a tensor containing probabilities or logits for each
-      observation. If preds has values outside [0,1] range we consider the input to be logits and will auto apply
-      sigmoid per element.
-    - ``target`` (int tensor): ``(N, C, ...)``. Target should be a tensor containing ground truth labels, and therefore
-      only contain {0,1} values (except if `ignore_index` is specified).
+    - ``preds`` (:class:`~torch.Tensor`): A float tensor of shape ``(N, C, ...)``. Preds should be a tensor containing
+      probabilities or logits for each observation. If preds has values outside [0,1] range we consider the input to
+      be logits and will auto apply sigmoid per element.
+    - ``target`` (:class:`~torch.Tensor`): An int tensor of shape ``(N, C, ...)``. Target should be a tensor containing
+      ground truth labels, and therefore only contain {0,1} values (except if `ignore_index` is specified).
 
-    Additional dimension ``...`` will be flattened into the batch dimension.
+    .. note::
+       Additional dimension ``...`` will be flattened into the batch dimension.
 
-    The implementation both supports calculating the metric in a non-binned but accurate version and a binned version
-    that is less accurate but more memory efficient. Setting the `thresholds` argument to `None` will activate the
-    non-binned  version that uses memory of size :math:`\mathcal{O}(n_{samples})` whereas setting the `thresholds`
-    argument to either an integer, list or a 1d tensor will use a binned version that uses memory of
-    size :math:`\mathcal{O}(n_{thresholds} \times n_{labels})` (constant memory).
+    As output to ``forward`` and ``compute`` the metric returns the following a tuple of either 3 tensors or
+    3 lists containing:
+
+    - ``precision`` (:class:`~torch.Tensor` or :class:`~List`): if `thresholds=None` a list for each label is returned
+      with an 1d tensor of size ``(n_thresholds+1, )`` with precision values (length may differ between labels). If
+      `thresholds` is set to something else, then a single 2d tensor of size ``(n_labels, n_thresholds+1)`` with
+      precision values is returned.
+    - ``recall`` (:class:`~torch.Tensor` or :class:`~List`): if `thresholds=None` a list for each label is returned
+      with an 1d tensor of size ``(n_thresholds+1, )`` with recall values (length may differ between labels). If
+      `thresholds` is set to something else, then a single 2d tensor of size ``(n_labels, n_thresholds+1)`` with recall
+      values is returned.
+    - ``thresholds`` (:class:`~torch.Tensor` or :class:`~List`): if `thresholds=None` a list for each label is
+      returned with an 1d tensor of size ``(n_thresholds, )`` with increasing threshold values (length may differ
+      between labels). If `threshold` is set to something else, then a single 1d tensor of size ``(n_thresholds, )``
+      is returned with shared threshold values for all labels.
+
+    .. note::
+       The implementation both supports calculating the metric in a non-binned but accurate version and a binned version
+       that is less accurate but more memory efficient. Setting the `thresholds` argument to `None` will activate the
+       non-binned  version that uses memory of size :math:`\mathcal{O}(n_{samples})` whereas setting the `thresholds`
+       argument to either an integer, list or a 1d tensor will use a binned version that uses memory of
+       size :math:`\mathcal{O}(n_{thresholds} \times n_{labels})` (constant memory).
 
     Args:
         preds: Tensor with predictions
@@ -319,19 +343,6 @@ class MultilabelPrecisionRecallCurve(Metric):
         validate_args: bool indicating if input arguments and tensors should be validated for correctness.
             Set to ``False`` for faster computations.
 
-    Returns:
-        (tuple): a tuple of either 3 tensors or 3 lists containing
-
-        - precision: if `thresholds=None` a list for each label is returned with an 1d tensor of size (n_thresholds+1, )
-          with precision values (length may differ between labels). If `thresholds` is set to something else,
-          then a single 2d tensor of size (n_labels, n_thresholds+1) with precision values is returned.
-        - recall: if `thresholds=None` a list for each label is returned with an 1d tensor of size (n_thresholds+1, )
-          with recall values (length may differ between labels). If `thresholds` is set to something else,
-          then a single 2d tensor of size (n_labels, n_thresholds+1) with recall values is returned.
-        - thresholds: if `thresholds=None` a list for each label is returned with an 1d tensor of size (n_thresholds, )
-          with increasing threshold values (length may differ between labels). If `threshold` is set to something else,
-          then a single 1d tensor of size (n_thresholds, ) is returned with shared threshold values for all labels.
-
     Example:
         >>> from torchmetrics.classification import MultilabelPrecisionRecallCurve
         >>> preds = torch.tensor([[0.75, 0.05, 0.35],
@@ -342,8 +353,8 @@ class MultilabelPrecisionRecallCurve(Metric):
         ...                        [0, 0, 0],
         ...                        [0, 1, 1],
         ...                        [1, 1, 1]])
-        >>> metric = MultilabelPrecisionRecallCurve(num_labels=3, thresholds=None)
-        >>> precision, recall, thresholds = metric(preds, target)
+        >>> mlprc = MultilabelPrecisionRecallCurve(num_labels=3, thresholds=None)
+        >>> precision, recall, thresholds = mlprc(preds, target)
         >>> precision  # doctest: +NORMALIZE_WHITESPACE
         [tensor([0.5000, 0.5000, 1.0000, 1.0000]), tensor([0.6667, 0.5000, 0.0000, 1.0000]),
          tensor([0.7500, 1.0000, 1.0000, 1.0000])]
@@ -353,8 +364,8 @@ class MultilabelPrecisionRecallCurve(Metric):
         >>> thresholds  # doctest: +NORMALIZE_WHITESPACE
         [tensor([0.0500, 0.4500, 0.7500]), tensor([0.5500, 0.6500, 0.7500]),
          tensor([0.0500, 0.3500, 0.7500])]
-        >>> metric = MultilabelPrecisionRecallCurve(num_labels=3, thresholds=5)
-        >>> metric(preds, target)  # doctest: +NORMALIZE_WHITESPACE
+        >>> mlprc = MultilabelPrecisionRecallCurve(num_labels=3, thresholds=5)
+        >>> mlprc(preds, target)  # doctest: +NORMALIZE_WHITESPACE
         (tensor([[0.5000, 0.5000, 1.0000, 1.0000, 0.0000, 1.0000],
                  [0.5000, 0.6667, 0.6667, 0.0000, 0.0000, 1.0000],
                  [0.7500, 1.0000, 1.0000, 1.0000, 0.0000, 1.0000]]),
