@@ -87,7 +87,7 @@ def binary_recall_at_fixed_precision(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tuple[Tensor, Tensor]:
-    r"""Computes the higest possible recall value given the minimum precision thresholds provided for binary tasks.
+    r"""Computes the highest possible recall value given the minimum precision thresholds provided for binary tasks.
     This is done by first calculating the precision-recall curve for different thresholds and the find the recall
     for a given precision level.
 
@@ -97,7 +97,7 @@ def binary_recall_at_fixed_precision(
       observation. If preds has values outside [0,1] range we consider the input to be logits and will auto apply
       sigmoid per element.
     - ``target`` (int tensor): ``(N, ...)``. Target should be a tensor containing ground truth labels, and therefore
-      only contain {0,1} values (except if `ignore_index` is specified).
+      only contain {0,1} values (except if `ignore_index` is specified). The value 1 always encodes the positive class.
 
     Additional dimension ``...`` will be flattened into the batch dimension.
 
@@ -186,7 +186,7 @@ def multiclass_recall_at_fixed_precision(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tuple[Tensor, Tensor]:
-    r"""Computes the higest possible recall value given the minimum precision thresholds provided for multiclass
+    r"""Computes the highest possible recall value given the minimum precision thresholds provided for multiclass
     tasks. This is done by first calculating the precision-recall curve for different thresholds and the find the
     recall for a given precision level.
 
@@ -294,7 +294,7 @@ def multilabel_recall_at_fixed_precision(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Tuple[Tensor, Tensor]:
-    r"""Computes the higest possible recall value given the minimum precision thresholds provided for multilabel
+    r"""Computes the highest possible recall value given the minimum precision thresholds provided for multilabel
     tasks. This is done by first calculating the precision-recall curve for different thresholds and the find the
     recall for a given precision level.
 
@@ -375,7 +375,7 @@ def recall_at_fixed_precision(
     ignore_index: Optional[int] = None,
     validate_args: bool = True,
 ) -> Union[Tensor, Tuple[Tensor, Tensor, Tensor], Tuple[List[Tensor], List[Tensor], List[Tensor]]]:
-    r"""Computes the higest possible recall value given the minimum precision thresholds provided. This is done by
+    r"""Computes the highest possible recall value given the minimum precision thresholds provided. This is done by
     first calculating the precision-recall curve for different thresholds and the find the recall for a given
     precision level.
 
