@@ -51,8 +51,8 @@ class Metric(Module, ABC):
     call of ``update()`` and are synchronized across processes when ``compute()`` is called.
 
     Note:
-        Metric state variables can either be ``torch.Tensors`` or an empty list which can we used
-        to store `torch.Tensors``.
+        Metric state variables can either be :class:`~torch.Tensor` or an empty list which can we used
+        to store :class:`~torch.Tensor`.
 
     Note:
         Different metrics only override ``update()`` and not ``forward()``. A call to ``update()``
@@ -155,8 +155,8 @@ class Metric(Module, ABC):
 
         Args:
             name: The name of the state variable. The variable will then be accessible at ``self.name``.
-            default: Default value of the state; can either be a ``torch.Tensor`` or an empty list. The state will be
-                reset to this value when ``self.reset()`` is called.
+            default: Default value of the state; can either be a :class:`~torch.Tensor` or an empty list.
+                The state will be reset to this value when ``self.reset()`` is called.
             dist_reduce_fx (Optional): Function to reduce state across multiple processes in distributed mode.
                 If value is ``"sum"``, ``"mean"``, ``"cat"``, ``"min"`` or ``"max"`` we will use ``torch.sum``,
                 ``torch.mean``, ``torch.cat``, ``torch.min`` and ``torch.max``` respectively, each with argument
@@ -171,9 +171,10 @@ class Metric(Module, ABC):
 
             The metric states would be synced as follows
 
-            - If the metric state is ``torch.Tensor``, the synced value will be a stacked ``torch.Tensor`` across
-              the process dimension if the metric state was a ``torch.Tensor``. The original ``torch.Tensor`` metric
-              state retains dimension and hence the synchronized output will be of shape ``(num_process, ...)``.
+            - If the metric state is :class:`~torch.Tensor`, the synced value will be a stacked :class:`~torch.Tensor`
+              across the process dimension if the metric state was a :class:`~torch.Tensor`. The original
+              :class:`~torch.Tensor` metric state retains dimension and hence the synchronized output will be of shape
+              ``(num_process, ...)``.
 
             - If the metric state is a ``list``, the synced value will be a ``list`` containing the
               combined elements from all processes.
@@ -899,7 +900,6 @@ class CompositionalMetric(Metric):
             self.metric_b.update(*args, **self.metric_b._filter_kwargs(**kwargs))
 
     def compute(self) -> Any:
-
         # also some parsing for kwargs?
         if isinstance(self.metric_a, Metric):
             val_a = self.metric_a.compute()
@@ -918,7 +918,6 @@ class CompositionalMetric(Metric):
 
     @torch.jit.unused
     def forward(self, *args: Any, **kwargs: Any) -> Any:
-
         val_a = (
             self.metric_a(*args, **self.metric_a._filter_kwargs(**kwargs))
             if isinstance(self.metric_a, Metric)
